<?php
/*
 * Copyright (c) 2008 Karri "Blaze" Kahelin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
require_once('Not_Connected_Exception.php');
require_once('Query.php');

/**
 * Database frontend class for MySQL database
 *
 * All methods override superclass ones, see superclass for documentation
 */
class MysqlQuery extends Query {
	protected function __construct($prefix) {
		parent::__construct($prefix);

		$this->s['tables_exist'] = "SHOW TABLE STATUS LIKE " .
			"'%prefix%pictures';";
		$this->s['create_tables'] =
			"CREATE TABLE `%prefix%pictures` (
			`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
			`filename` TEXT NOT NULL ,
			`category` TEXT NOT NULL ,
			`added` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
			`taken` TIMESTAMP NULL DEFAULT NULL ,
			`width` SMALLINT UNSIGNED NULL DEFAULT NULL ,
			`height` SMALLINT UNSIGNED NULL DEFAULT NULL ,
			`cam_manufacturer` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`cam_model` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`shutter_speed` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`subject_distance` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`focal_length` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`exposure_time` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`location` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`photographer` VARCHAR( 255 ) NULL DEFAULT NULL ,
			`description` TEXT DEFAULT NULL ,
			`format` VARCHAR( 64 ) NOT NULL ,
			`size` INT UNSIGNED NOT NULL ,
			PRIMARY KEY ( `id` ) 
			) DEFAULT CHARSET = utf8 ENGINE = InnoDB;

			CREATE TABLE `%prefix%comments` (
			`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
			`pic_id` INT UNSIGNED NOT NULL ,
			`comment` TEXT NOT NULL ,
			`username` TEXT NOT NULL ,
			`added` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ,
			INDEX `pic_id_index` ( `pic_id` ) ,
			PRIMARY KEY ( `id` ) ,
			FOREIGN KEY ( `pic_id` )
			REFERENCES `%prefix%pictures` ( `id` )
			ON DELETE CASCADE
			) DEFAULT CHARSET = utf8 ENGINE = InnoDB;

			CREATE TABLE `%prefix%tags` (
			`id` INT UNSIGNED NOT NULL AUTO_INCREMENT ,
			`name` VARCHAR( 255 ) NOT NULL ,
			PRIMARY KEY ( `id` )
			) DEFAULT CHARSET = utf8 ENGINE = InnoDB;

			CREATE TABLE `%prefix%tag_pic` (
			`tag_id` INT UNSIGNED NOT NULL ,
			`pic_id` INT UNSIGNED NOT NULL ,
			INDEX `tag_id_index` ( `tag_id` ) ,
			INDEX `pic_id_index` ( `pic_id` ) ,
			FOREIGN KEY ( `tag_id` )
			REFERENCES `%prefix%tags` ( `id` )
			ON DELETE CASCADE ,
			FOREIGN KEY ( `pic_id` )
			REFERENCES `%prefix%pictures` ( `id` )
			ON DELETE CASCADE
			) DEFAULT CHARSET = utf8 ENGINE = InnoDB;";
	}

	public function connect($dsn, $user, $pass) {
		$retval = parent::connect($dsn, $user, $pass);
		$this->pdo->setAttribute(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY,
			true);
		return $retval;
	}

	public function tablesExist() {
		if(!$this->isConnected()) {
			throw new Not_Connected_Exception();
		}
		$stmt = $this->pdo->query($this->s['tables_exist']);
		if($stmt->rowCount() == 0) {
			return false;
		} else {
			return true;
		}
	}
}
