<?php
/*
 * Copyright (c) 2008 Karri "Blaze" Kahelin
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
require_once('utils.php');
require_once('File_Not_Found_Exception.php');

/**
 * Readonly interface to configuration file
 */
class Settings {
	private $_s = NULL;

	/**
	 * Constructs new Settings-object based on values from given
	 * configuration file
	 *
	 * @param filename name of the configuration file or NULL to not
	 *		   to use one
	 */
	public function __construct($filename = 'LocalSettings.php') {
		$s = array();
		// initialize some settings with stupid defaults
		$s['image_dir'] = './images/';
		$s['thumb_dir'] = './thumbs/';
		$s['thumb_width'] = 100;
		$s['thumb_height'] = 100;
		$s['image_width'] = 800;
		$s['image_height'] = 600;
		$s['per_page'] = 30;
		$s['theme'] = 'default';
		$s['prefix'] = 'sg_';
		$s['dbdsn'] = 'sqlite:' . dirname($_SERVER['SCRIPT_FILENAME']) .
			'/sqlitedb.sq3';
		$s['public_login'] = false;
		$s['public_info'] = true;
		$s['admin_pass'] = 'changeme';
		if($filename !== NULL) {
			if(!@include_once($filename)) {
				throw new File_Not_Found_Exception($filename);
			}
		}
		$this->_s = $s;
		$this->_s['image_dir'] = ensureslash($this->_s['image_dir']);
		$this->_s['thumb_dir'] = ensureslash($this->_s['thumb_dir']);
	}

	/**
	 * Returns a setting
	 *
	 * @param name name of the setting
	 *
	 * @return value of the desired setting or NULL if not set
	 */
	public function get($name) {
		return isset($this->_s[$name]) ? $this->_s[$name] : NULL;
	}
}
?>
